Templated-docs settings
=======================

Some settings can be utilised to alter the package behaviour:

* **TEMPLATED_DOCS_LIBREOFFICE_PATH** - a path to the LibreOffice installation's `program` folder. Defaults to ``/usr/share/libreoffice/program``.
